@@ -11,6 +11,7 @@ SEXP R_dggev(SEXP JOBVL, SEXP JOBVR, SEXP N,
 	int n = INTEGER(N)[0], total_length;
 	SEXP S, T;
 	char CS_JOBVL = CHARPT(JOBVL, 0)[0], CS_JOBVR = CHARPT(JOBVR, 0)[0];
+	int CF_wrap;
 
 	/* Protect R objects. */
 	PROTECT(S = allocMatrix(REALSXP, n, n));
@@ -23,40 +24,23 @@ SEXP R_dggev(SEXP JOBVL, SEXP JOBVR, SEXP N,
 
 	/* Call Fortran. */
 	if(CS_JOBVL == 'V' && CS_JOBVR == 'V'){
-		F77_CALL(dggev)("V", "V",
-			INTEGER(N), REAL(S), INTEGER(LDA),
-			REAL(T), INTEGER(LDB),
-			REAL(ALPHAR), REAL(ALPHAI), REAL(BETA),
-			REAL(VL), INTEGER(LDVL), REAL(VR), INTEGER(LDVR),
-			REAL(WORK), INTEGER(LWORK),
-			INTEGER(INFO));
+		CF_wrap = 0;
 	} else if(CS_JOBVL == 'N' && CS_JOBVR == 'V'){
-		F77_CALL(dggev)("N", "V",
-			INTEGER(N), REAL(S), INTEGER(LDA),
-			REAL(T), INTEGER(LDB),
-			REAL(ALPHAR), REAL(ALPHAI), REAL(BETA),
-			REAL(VL), INTEGER(LDVL), REAL(VR), INTEGER(LDVR),
-			REAL(WORK), INTEGER(LWORK),
-			INTEGER(INFO));
+		CF_wrap = 1;
 	} else if(CS_JOBVL == 'V' && CS_JOBVR == 'N'){
-		F77_CALL(dggev)("V", "N",
-			INTEGER(N), REAL(S), INTEGER(LDA),
-			REAL(T), INTEGER(LDB),
-			REAL(ALPHAR), REAL(ALPHAI), REAL(BETA),
-			REAL(VL), INTEGER(LDVL), REAL(VR), INTEGER(LDVR),
-			REAL(WORK), INTEGER(LWORK),
-			INTEGER(INFO));
+		CF_wrap = 2;
 	} else if(CS_JOBVL == 'N' && CS_JOBVR == 'N'){
-		F77_CALL(dggev)("N", "N",
-			INTEGER(N), REAL(S), INTEGER(LDA),
-			REAL(T), INTEGER(LDB),
-			REAL(ALPHAR), REAL(ALPHAI), REAL(BETA),
-			REAL(VL), INTEGER(LDVL), REAL(VR), INTEGER(LDVR),
-			REAL(WORK), INTEGER(LWORK),
-			INTEGER(INFO));
+		CF_wrap = 3;
 	} else{
 		REprintf("Input (CHARACTER) types are not implemented.\n");
 	}
+	F77_CALL(wdggev)(&CF_wrap,
+		INTEGER(N), REAL(S), INTEGER(LDA),
+		REAL(T), INTEGER(LDB),
+		REAL(ALPHAR), REAL(ALPHAI), REAL(BETA),
+		REAL(VL), INTEGER(LDVL), REAL(VR), INTEGER(LDVR),
+		REAL(WORK), INTEGER(LWORK),
+		INTEGER(INFO));
 
 	/* Return. */
 	UNPROTECT(2);
