@@ -10,6 +10,7 @@ SEXP R_zggev(SEXP JOBVL, SEXP JOBVR, SEXP N,
 	int n = INTEGER(N)[0], total_length;
 	SEXP S, T;
 	char CS_JOBVL = CHARPT(JOBVL, 0)[0], CS_JOBVR = CHARPT(JOBVR, 0)[0];
+	int CF_wrap;
 
 	/* Protect R objects. */
 	PROTECT(S = allocMatrix(CPLXSXP, n, n));
@@ -22,44 +23,24 @@ SEXP R_zggev(SEXP JOBVL, SEXP JOBVR, SEXP N,
 
 	/* Call Fortran. */
 	if(CS_JOBVL == 'V' && CS_JOBVR == 'V'){
-		F77_CALL(zggev)("V", "V",
-			INTEGER(N), COMPLEX(S), INTEGER(LDA),
-			COMPLEX(T), INTEGER(LDB),
-			COMPLEX(ALPHA), COMPLEX(BETA), COMPLEX(VL),
-			INTEGER(LDVL),
-			COMPLEX(VR), INTEGER(LDVR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(INFO));
+		CF_wrap = 0;
 	} else if(CS_JOBVL == 'N' && CS_JOBVR == 'V'){
-		F77_CALL(zggev)("N", "V",
-			INTEGER(N), COMPLEX(S), INTEGER(LDA),
-			COMPLEX(T), INTEGER(LDB),
-			COMPLEX(ALPHA), COMPLEX(BETA), COMPLEX(VL),
-			INTEGER(LDVL),
-			COMPLEX(VR), INTEGER(LDVR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(INFO));
+		CF_wrap = 1;
 	} else if(CS_JOBVL == 'V' && CS_JOBVR == 'N'){
-		F77_CALL(zggev)("V", "N",
-			INTEGER(N), COMPLEX(S), INTEGER(LDA),
-			COMPLEX(T), INTEGER(LDB),
-			COMPLEX(ALPHA), COMPLEX(BETA), COMPLEX(VL),
-			INTEGER(LDVL),
-			COMPLEX(VR), INTEGER(LDVR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(INFO));
+		CF_wrap = 2;
 	} else if(CS_JOBVL == 'N' && CS_JOBVR == 'N'){
-		F77_CALL(zggev)("N", "N",
-			INTEGER(N), COMPLEX(S), INTEGER(LDA),
-			COMPLEX(T), INTEGER(LDB),
-			COMPLEX(ALPHA), COMPLEX(BETA), COMPLEX(VL),
-			INTEGER(LDVL),
-			COMPLEX(VR), INTEGER(LDVR), COMPLEX(WORK),
-			INTEGER(LWORK),
-			REAL(RWORK), INTEGER(INFO));
+		CF_wrap = 3;
 	} else{
 		REprintf("Input (CHARACTER) types are not implemented.\n");
 	}
+	F77_CALL(wzggev)(&CF_wrap,
+		INTEGER(N), COMPLEX(S), INTEGER(LDA),
+		COMPLEX(T), INTEGER(LDB),
+		COMPLEX(ALPHA), COMPLEX(BETA), COMPLEX(VL),
+		INTEGER(LDVL),
+		COMPLEX(VR), INTEGER(LDVR), COMPLEX(WORK),
+		INTEGER(LWORK),
+		REAL(RWORK), INTEGER(INFO));
 
 	/* Return. */
 	UNPROTECT(2);
