@@ -7,3 +7,6 @@ pdflatex QZ-guide.Rnw
 pdflatex QZ-guide.Rnw
 pdflatex QZ-guide.Rnw
 rm *.aux *.bbl *.blg *.log *.out *.toc
+
+mv -f *.pdf ../inst/doc/
+cp -f *.Rnw ../inst/doc/
